@@ -5,5 +5,5 @@ redis_port = 6379
 
 
 apps = [
-    '{app_name}',
+    'core',
 ]
