@@ -13,8 +13,8 @@ def project_cli():
 @click.argument('name')
 def make(name):
     """
-    Will make simple project, with basic structure, predefined config, and
-    sample functions.
+    Makes a project, based on default template. It will contain all main
+    stairs components and default app `core`.
     """
 
     default_project_path = os.path.join(_get_stairs_source_path(),
@@ -24,13 +24,11 @@ def make(name):
 
     path_to_user_project = './%s' % name
     copy_tree(default_project_path, path_to_user_project)
-    copy_tree(default_app_path, os.path.join(path_to_user_project, name))
+    copy_tree(default_app_path, os.path.join(path_to_user_project, 'core'))
 
     with open(os.path.join(path_to_user_project, 'config.py'), 'r') as config_f:
         config_body = config_f.read()
 
-    config_body = config_body.format(app_name=name)
-
     with open(os.path.join(path_to_user_project, 'config.py'), 'w') as config_f:
         config_f.write(config_body)
 
